@@ -18,18 +18,42 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ArgV.cc,v 1.7 1999/10/04 17:11:01 lav Exp $ */
+/* $Id: ArgV.cc,v 1.10 2001/10/03 08:13:36 lav Exp $ */
 
 #include <config.h>
 
 #include "getopt.h"
 #include "xmalloc.h"
+#include "misc.h"
 #include "ArgV.h"
 
+ArgV::ArgV(const char *a0, const char *args)
+{
+   int argc;
+   char **argv = tokenize(args, &argc);
+   Init(argc,argv);
+   tokenize_free(argv);
+
+   insarg(0, a0);
+}
+
+void ArgV::GetRoom(int n)
+{
+   // alloc one extra for trailing zero
+   int size=((n+4)&~3);
+   if(size>allocated)
+   {
+      v=(char**)xrealloc(v,sizeof(*v)*size);
+      allocated=size;
+   }
+}
+
 void ArgV::Init(int new_c,const char * const *new_v)
 {
    c=new_c;
-   v=(char**)xmalloc(sizeof(char*)*(c+1));
+   v=0;
+   allocated=0;
+   GetRoom(c);
    int i;
    for(i=0; i<c; i++)
       v[i]=xstrdup(new_v[i]);
@@ -37,12 +61,20 @@ void ArgV::Init(int new_c,const char * const *new_v)
    ind=0;
 }
 
+ArgV::~ArgV()
+{
+   int i;
+   for(i=0; i<c; i++)
+      xfree(v[i]);
+   xfree(v);
+}
+
 void ArgV::Empty()
 {
    int i;
    for(i=0; i<c; i++)
-      free(v[i]);
-   v=(char**)xrealloc(v,sizeof(*v));
+      xfree(v[i]);
+   GetRoom(0);
    v[0]=0;
    c=0;
    ind=0;
@@ -99,7 +131,7 @@ char *ArgV::Combine(int start) const
 
 void ArgV::Append(const char *s)
 {
-   v=(char**)xrealloc(v,sizeof(*v)*(c+2));
+   GetRoom(c+1);
    v[c++]=xstrdup(s);
    v[c]=0;
 }
@@ -133,7 +165,7 @@ void ArgV::insarg(int n,const char *s)
       Append(s);
    else
    {
-      v=(char**)xrealloc(v,sizeof(*v)*(c+2));
+      GetRoom(c+1);
       // copy with trailing null pointer
       memmove(v+n+1,v+n,(count()-n+1)*sizeof(*v));
       c++;
