@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ArgV.h,v 1.10 2000/02/12 17:04:38 lav Exp $ */
+/* $Id: ArgV.h,v 1.12 2001/10/12 10:50:06 lav Exp $ */
 
 #ifndef ARGV_H
 #define ARGV_H
@@ -36,8 +36,10 @@ class ArgV
 public:
    ArgV() { Init(0,0); }
    ArgV(const char *a0) { Init(1,&a0); }
+   ArgV(const char *a0, const char *args);
    void Empty();
    void Append(const char *);
+   void Add(const char *a) { Append(a); } // alias
    ArgV(const ArgV& a) { Init(a.c,a.v); }
    ArgV(int new_c,const char * const *new_v) { Init(new_c,new_v); }
    ~ArgV();
