@@ -18,10 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CatJob.cc,v 1.19 2000/12/08 15:30:36 lav Exp $ */
+/* $Id: CatJob.cc,v 1.19.2.1 2002/01/15 16:20:20 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
+#include "trio.h"
 #include <errno.h>
 #include <unistd.h>
 
