@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CatJob.h,v 1.6 1999/12/22 20:06:55 lav Exp $ */
+/* $Id: CatJob.h,v 1.7 2000/07/19 07:24:14 lav Exp $ */
 
 #ifndef CATJOB_H
 #define CATJOB_H
@@ -34,6 +34,7 @@ protected:
    FDStream *global;
    const char *for_each;
    bool ascii;
+   bool auto_ascii;
 
    void	NextFile();
 
@@ -46,6 +47,7 @@ public:
    ~CatJob();
 
    void Ascii() { ascii=true; }
+   void Binary() { ascii=auto_ascii=false; }
 };
 
 #endif /* CATJOB_H */
