@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.cc,v 1.83 2001/10/25 10:46:33 lav Exp $ */
+/* $Id: CmdExec.cc,v 1.83.2.1 2002/01/24 10:48:45 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -1066,7 +1066,7 @@ bool CmdExec::needs_quotation(const char *buf)
    {
       if(isspace(*buf))
 	 return true;
-      if(*buf=='"' || *buf=='\\' || *buf=='&' || *buf=='|' || *buf=='>' || *buf==';')
+      if(strchr("\"'\\&|>;",*buf))
 	 return true;
       buf++;
    }
