@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.h,v 1.40 2001/05/10 14:44:23 lav Exp $ */
+/* $Id: CmdExec.h,v 1.42 2001/07/26 09:57:18 lav Exp $ */
 
 #ifndef CMDEXEC_H
 #define CMDEXEC_H
@@ -32,6 +32,8 @@
 #include "history.h"
 #include "bookmark.h"
 
+class QueueFeeder;
+
 extern History cwd_history;
 extern Bookmark lftp_bookmarks;
 
@@ -129,10 +131,8 @@ private:
    static CmdExec *chain;
    CmdExec *next;
 
-   bool is_queue;
-   char *queue_cwd;
-   char *queue_lcwd;
-   CmdExec *FindQueue();
+   QueueFeeder *has_queue;
+   CmdExec *GetQueue(bool create = true);
 
    FileAccess *saved_session;
    void ReuseSavedSession();
@@ -147,6 +147,9 @@ public:
    static bool needs_quotation(const char *buf);
    void FeedQuoted(const char *c);
    void AtExit();
+   void EmptyCmds();
+   bool WriteCmds(int fd) const;
+   bool ReadCmds(int fd); // does not clear queue before reading (appends)
 
    void SuspendJob(Job *j);
 
@@ -219,6 +222,7 @@ public:
    Job *builtin_restart();
    Job *builtin_glob();
    Job *builtin_queue();
+   Job *builtin_queue_edit();
 
    Job *default_cmd();
 
