@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CopyJob.cc,v 1.22 2000/09/07 18:51:38 lav Exp $ */
+/* $Id: CopyJob.cc,v 1.24 2001/11/06 13:15:32 lav Exp $ */
 
 #include <config.h>
 #include "CopyJob.h"
@@ -43,6 +43,19 @@ int CopyJob::Do()
       done=true;
       return MOVED;
    }
+   if(!c->WriteAllowed() && c->WritePending())
+   {
+      if(no_status_on_write)
+      {
+	 // clear status.
+	 const char *empty="";
+	 eprintf(empty);
+	 // disable status.
+	 NoStatus();
+      }
+      c->AllowWrite();
+      return MOVED;
+   }
    return STALL;
 }
 int CopyJob::Done()
@@ -109,6 +122,7 @@ CopyJob::CopyJob(FileCopy *c1,const char *name1,const char *op1)
    op=xstrdup(op1);
    done=false;
    no_status=false;
+   no_status_on_write=false;
 }
 CopyJob::~CopyJob()
 {
@@ -181,7 +195,6 @@ int CopyJobEnv::Do()
    count++;
    bytes+=j->GetBytesCount();
    time_spent+=j->GetTimeSpent();
-   time_spent+=j->GetTimeSpentMilli()/1000.0;
    return MOVED;
 }
 void CopyJobEnv::AddCopier(FileCopy *c,const char *n)
