@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.cc,v 1.84 2001/07/24 07:44:22 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.87 2001/10/09 12:26:04 lav Exp $ */
 
 #include <config.h>
 
@@ -33,6 +33,9 @@
 #include <errno.h>
 #include "ascii_ctype.h"
 #include <fcntl.h>
+/* Our autoconf test will switch to lib/fnmatch.c if the local fnmatch
+ * isn't GNU, so this should be OK. */
+#define _GNU_SOURCE
 #include <fnmatch.h>
 #include "LsCache.h"
 #include "xalloca.h"
@@ -447,24 +450,18 @@ void FileAccess::Connect(const char *host1,const char *port1)
    hostname=xstrdup(host1);
    xfree(portname);
    portname=xstrdup(port1);
-   xfree(cwd);
-   cwd=xstrdup(default_cwd);
-   xfree(home); home=0;
    DontSleep();
+   ResetLocationData();
 }
 
 void FileAccess::Login(const char *user1,const char *pass1)
 {
-   Disconnect();
+   Close();
    xfree(user);
    user=xstrdup(user1);
    xfree(pass);
    pass=xstrdup(pass1);
    pass_open=false;
-   xfree(cwd);
-   cwd=xstrdup(default_cwd);
-   xfree(home);
-   home=0;
 
    if(user && pass==0)
    {
@@ -488,6 +485,22 @@ void FileAccess::Login(const char *user1,const char *pass1)
 	 }
       }
    }
+   ResetLocationData();
+}
+
+void FileAccess::AnonymousLogin()
+{
+   Close();
+   xfree(user); user=0;
+   xfree(pass); pass=0;
+   pass_open=false;
+   ResetLocationData();
+}
+
+void FileAccess::ResetLocationData()
+{
+   xfree(cwd);  cwd=xstrdup(default_cwd);
+   xfree(home); home=0;
 }
 
 void FileAccess::SetPasswordGlobal(const char *p)
@@ -510,17 +523,6 @@ void FileAccess::SetPasswordGlobal(const char *p)
    }
 }
 
-void FileAccess::AnonymousLogin()
-{
-   Disconnect();
-   xfree(user); user=0;
-   xfree(pass); pass=0;
-   pass_open=false;
-   xfree(cwd);
-   cwd=xstrdup(default_cwd);
-   xfree(home);  home=0;
-}
-
 void FileAccess::GetInfoArray(struct fileinfo *info,int count)
 {
    Open(0,ARRAY_INFO);
@@ -1079,6 +1081,7 @@ Glob::Glob(const char *p)
    files_only=false;
    match_period=true;
    inhibit_tilde=true;
+   casefold=false;
 
    if(pattern[0]=='~')
    {
@@ -1126,6 +1129,9 @@ void Glob::add(const FileInfo *info)
    if(match_period)
       flags|=FNM_PERIOD;
 
+   if(casefold)
+      flags|=FNM_CASEFOLD;
+
    if(pattern[0]!=0
    && fnmatch(pattern, s, flags)!=0)
       return; // unmatched
