@@ -18,13 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.65 2001/10/25 10:46:33 lav Exp $ */
+/* $Id: FileAccess.h,v 1.65.2.1 2002/01/15 16:20:20 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
 
 #include "SMTask.h"
-#include <stdio.h>
+#include "trio.h"
 #include <time.h>
 #include <sys/types.h>
 
