@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileCopy.cc,v 1.70 2000/09/29 07:51:21 lav Exp $ */
+/* $Id: FileCopy.cc,v 1.76 2001/11/06 13:15:32 lav Exp $ */
 
 /* FileCopyPeer behaviour:
     1) when suspended, does nothing
@@ -182,7 +182,7 @@ int FileCopy::Do()
 	    }
 	    debug((9,_("copy: put rolled back to %lld, seeking get accordingly\n"),
 		     (long long)put->GetRealPos()));
-	    debug((10,_("copy: get position was %lld\n"),
+	    debug((10,"copy: get position was %lld\n",
 		     (long long)get->GetRealPos()));
 	    get->Seek(put->GetRealPos());
 	    return MOVED;
@@ -220,7 +220,7 @@ int FileCopy::Do()
       get->Get(&b,&s);
       if(b==0) // eof
       {
-	 debug((10,_("copy: get hit eof\n")));
+	 debug((10,"copy: get hit eof\n"));
       eof:
 	 put->Resume();
 	 if(line_buffer)
@@ -293,7 +293,7 @@ int FileCopy::Do()
 
       if(get->range_limit!=FILE_END && get->range_limit<=get->GetRealPos())
       {
-	 debug((10,_("copy: get reached range limit\n")));
+	 debug((10,"copy: get reached range limit\n"));
 	 goto eof;
       }
       return m;
@@ -315,7 +315,7 @@ int FileCopy::Do()
 
       if(!put->Done())
 	 return m;
-      debug((10,_("copy: put confirmed store\n")));
+      debug((10,"copy: put confirmed store\n"));
 
    pre_GET_DONE_WAIT:
       get->Empty();
@@ -324,7 +324,6 @@ int FileCopy::Do()
       state=GET_DONE_WAIT;
       m=MOVED;
       end_time=now;
-      end_time_ms=now_ms;
       Delete(put); put=0;
       /* fallthrough */
    case(GET_DONE_WAIT):
@@ -337,7 +336,7 @@ int FileCopy::Do()
       }
       if(!get->Done())
 	 return m;
-      debug((10,_("copy: get is finished - all done\n")));
+      debug((10,"copy: get is finished - all done\n"));
       state=ALL_DONE;
       Delete(get); get=0;
       return MOVED;
@@ -371,10 +370,6 @@ void FileCopy::Init()
    put_buf=0;
    put_eof_pos=0;
    bytes_count=0;
-   start_time=0;
-   start_time_ms=0;
-   end_time=0;
-   end_time_ms=0;
    fail_if_cannot_seek=false;
    remove_source_later=false;
    line_buffer=0;
@@ -558,18 +553,11 @@ const char *FileCopy::GetStatus()
    return buf;
 }
 
-time_t FileCopy::GetTimeSpent()
+double FileCopy::GetTimeSpent()
 {
-   if(start_time==0 || end_time==0 || end_time<start_time)
+   if(end_time<start_time)
       return 0;
-   return end_time-start_time;
-}
-int FileCopy::GetTimeSpentMilli()
-{
-   if(start_time==0 || end_time==0 || end_time<start_time
-   || (end_time==start_time && end_time_ms<start_time_ms))
-      return 0;
-   return end_time_ms-start_time_ms;
+   return TimeDiff(end_time,start_time);
 }
 
 FgData *FileCopy::GetFgData(bool fg)
@@ -658,6 +646,7 @@ FileCopyPeer::FileCopyPeer(direction m)
    range_limit=FILE_END;
    removing=false;
    use_cache=true;
+   write_allowed=true;
    Suspend();  // don't do anything too early
 }
 FileCopyPeer::~FileCopyPeer()
@@ -841,7 +830,7 @@ void FileCopyPeerFA::OpenSession()
       if(size!=NO_SIZE && size!=NO_SIZE_YET && seek_pos>=size && !ascii)
       {
       past_eof:
-	 debug((10,_("copy src: seek past eof (seek_pos=%lld, size=%lld)\n"),
+	 debug((10,"copy src: seek past eof (seek_pos=%lld, size=%lld)\n",
 		  (long long)seek_pos,(long long)size));
 	 pos=seek_pos;
 	 eof=true;
@@ -859,30 +848,6 @@ void FileCopyPeerFA::OpenSession()
 	 Save(0);
 	 Allocate(s);
 	 memmove(buffer+buffer_ptr,b,s);
-      #ifndef NATIVE_CRLF
-	 if(ascii)
-	 {
-	    char *buf=buffer+buffer_ptr;
-	    // find where line ends.
-	    char *cr=buf;
-	    for(;;)
-	    {
-	       cr=(char *)memchr(cr,'\r',s-(cr-buf));
-	       if(!cr)
-		  break;
-	       if(cr-buf<s-1 && cr[1]=='\n')
-	       {
-		  memmove(cr,cr+1,s-(cr-buf)-1);
-		  s--;
-		  if(s<=1)
-		     break;
-	       }
-	       else if(cr-buf==s-1)
-		  break;
-	       cr++;
-	    }
-	 }
-      #endif	 // NATIVE_CRLF
 	 in_buffer=s;
 	 pos=seek_pos;
 	 eof=true;
@@ -1192,6 +1157,8 @@ FileCopyPeerFDStream::FileCopyPeerFDStream(FDStream *o,direction m)
 	 seek_base=0;
       }
    }
+   if(stream->usesfd(1))
+      write_allowed=false;
 }
 FileCopyPeerFDStream::~FileCopyPeerFDStream()
 {
@@ -1270,9 +1237,8 @@ int FileCopyPeerFDStream::getfd()
 int FileCopyPeerFDStream::Do()
 {
    int m=STALL;
-   int res;
    if(Done() || Error())
-      return STALL;
+      return m;
    switch(mode)
    {
    case PUT:
@@ -1294,31 +1260,43 @@ int FileCopyPeerFDStream::Do()
 	 if(seek_pos==0)
 	    return m;
       }
-      res=Put_LL(buffer+buffer_ptr,in_buffer);
-      if(res>0)
+      if(!write_allowed)
+	 return m;
+      while(in_buffer>0)
       {
-	 in_buffer-=res;
-	 buffer_ptr+=res;
-	 return MOVED;
+	 int res=Put_LL(buffer+buffer_ptr,in_buffer);
+	 if(res>0)
+	 {
+	    in_buffer-=res;
+	    buffer_ptr+=res;
+	    m=MOVED;
+	 }
+	 if(res<0)
+	    return MOVED;
+	 if(res==0)
+	    break;
       }
-      if(res<0)
-	 return MOVED;
       break;
 
    case GET:
       if(eof)
 	 return m;
-      res=Get_LL(GET_BUFSIZE);
-      if(res>0)
+      while(in_buffer<GET_BUFSIZE)
       {
-	 in_buffer+=res;
-	 SaveMaxCheck(0);
-	 return MOVED;
+	 int res=Get_LL(GET_BUFSIZE);
+	 if(res>0)
+	 {
+	    in_buffer+=res;
+	    SaveMaxCheck(0);
+	    m=MOVED;
+	 }
+	 if(res<0)
+	    return MOVED;
+	 if(eof)
+	    return MOVED;
+	 if(res==0)
+	    break;
       }
-      if(res<0)
-	 return MOVED;
-      if(eof)
-	 return MOVED;
       break;
    }
    return m;
@@ -1418,7 +1396,7 @@ int FileCopyPeerFDStream::Get_LL(int len)
    res=read(fd,buffer+buffer_ptr+in_buffer,len);
    if(res==-1)
    {
-      if(errno==EAGAIN || errno==EINTR)
+      if(E_RETRY(errno))
       {
 	 Block(fd,POLLIN);
 	 return 0;
@@ -1498,7 +1476,7 @@ int FileCopyPeerFDStream::Put_LL(const char *buf,int len)
    int res=write(fd,buf,len);
    if(res<0)
    {
-      if(errno==EAGAIN || errno==EINTR)
+      if(E_RETRY(errno))
       {
 	 Block(fd,POLLOUT);
 	 return 0;
