@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.cc,v 1.16 2001/08/27 13:56:49 lav Exp $ */
+/* $Id: FileSet.cc,v 1.21 2001/11/09 13:36:26 lav Exp $ */
 
 #include <config.h>
 #include "FileSet.h"
@@ -27,6 +27,11 @@
 #include <sys/stat.h>
 #include <utime.h>
 #include <stdlib.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <fnmatch.h>
+#include <assert.h>
+
 #include "misc.h"
 #include "ResMgr.h"
 
@@ -60,6 +65,7 @@ void FileInfo::SetName(const char *n)
 
 void FileSet::Add(FileInfo *fi)
 {
+   assert(!sorted);
    if(!(fi->defined & fi->NAME))
    {
       delete fi;
@@ -72,13 +78,14 @@ void FileSet::Add(FileInfo *fi)
       delete fi;
       return;
    }
-   files=(FileInfo**)xrealloc(files,(++fnum)*sizeof(*files));
+   files=files_sort=(FileInfo**)xrealloc(files,(++fnum)*sizeof(*files));
    memmove(files+pos+1, files+pos, sizeof(*files)*(fnum-pos-1));
    files[pos]=fi;
 }
 
 void FileSet::Sub(int i)
 {
+   assert(!sorted);
    if(i>=fnum)
       abort();
    delete files[i];
@@ -129,24 +136,93 @@ void FileSet::Merge(char **list)
    }
 }
 
+/* we don't copy the sort state--nothing needs it, and it'd
+ * be a bit of a pain to implement. */
 FileSet::FileSet(FileSet const *set)
 {
    ind=set->ind;
    fnum=set->fnum;
+   sorted = false;
    if(fnum==0)
-      files=0;
+      files=files_sort=0;
    else
-      files=(FileInfo**)xmalloc(fnum*sizeof(*files));
+      files=files_sort=(FileInfo**)xmalloc(fnum*sizeof(*files));
    for(int i=0; i<fnum; i++)
       files[i]=new FileInfo(*(set->files[i]));
 }
 
+static int (*compare)(const char *s1, const char *s2);
+
+static int sort_name(const void *s1, const void *s2)
+{
+   const FileInfo *p1 = *(const FileInfo **) s1;
+   const FileInfo *p2 = *(const FileInfo **) s2;
+   return compare(p1->name, p2->name);
+}
+
+static int sort_size(const void *s1, const void *s2)
+{
+   const FileInfo *p1 = *(const FileInfo **) s1;
+   const FileInfo *p2 = *(const FileInfo **) s2;
+   if(p1->size > p2->size) return -1;
+   if(p1->size < p2->size) return 1;
+   return 0;
+}
+
+static int sort_dirs(const void *s1, const void *s2)
+{
+   const FileInfo *p1 = *(const FileInfo **) s1;
+   const FileInfo *p2 = *(const FileInfo **) s2;
+   if(p1->filetype == FileInfo::DIRECTORY && !p2->filetype == FileInfo::DIRECTORY) return -1;
+   if(!p1->filetype == FileInfo::DIRECTORY && p2->filetype == FileInfo::DIRECTORY) return 1;
+   return 0;
+}
+
+/* files_sort is an alias of files when sort == NAME (since
+ * files is always sorted by name), and an independant array
+ * of pointers (pointing to the same data) otherwise. */
+void FileSet::Sort(sort_e newsort, bool casefold)
+{
+   if(newsort == BYNAME && !casefold) {
+      Unsort();
+      return;
+   }
+
+   if(files_sort == files) {
+      files_sort=(FileInfo**)xmalloc(fnum*sizeof(FileInfo *));
+      for(int i=0; i < fnum; i++)
+	 files_sort[i] = files[i];
+   }
+
+   sorted = true;
+
+   if(casefold) compare = strcasecmp;
+   else compare = strcmp;
+
+   switch(newsort) {
+   case BYNAME: qsort(files_sort, fnum, sizeof(FileInfo *), sort_name); break;
+   case BYSIZE: qsort(files_sort, fnum, sizeof(FileInfo *), sort_size); break;
+   case DIRSFIRST: qsort(files_sort, fnum, sizeof(FileInfo *), sort_dirs); break;
+   }
+}
+
+/* Remove the current sort, allowing new entries to be added.
+ * (Nothing uses this ... */
+void FileSet::Unsort()
+{
+   if(!sorted) return;
+   xfree(files_sort);
+   files_sort = files;
+   sorted = false;
+}
+
 void FileSet::Empty()
 {
+   Unsort();
    for(int i=0; i<fnum; i++)
       delete files[i];
    xfree(files);
-   files=0;
+   files=0; files_sort=0;
    fnum=0;
    ind=0;
 }
@@ -313,11 +389,11 @@ int FileSet::FindGEIndByName(const char *name) const
 
 FileInfo *FileSet::FindByName(const char *name) const
 {
-   for(int i=0; i<fnum; i++)
-   {
-      if(!strcmp(files[i]->name,name))
-	 return files[i];
-   }
+   int n = FindGEIndByName(name);
+
+   if(n < fnum && !strcmp(files[n]->name,name))
+      return files[n];
+
    return 0;
 }
 
@@ -336,6 +412,21 @@ void  FileSet::Exclude(const char *prefix,regex_t *exclude,regex_t *include)
    }
 }
 
+void  FileSet::Exclude(const char *prefix,const char *exclude,const char *include)
+{
+   for(int i=0; i<fnum; i++)
+   {
+      const char *name=dir_file(prefix,files[i]->name);
+      if(!(include && fnmatch(include,name,0)==0)
+       && ((exclude && fnmatch(exclude,name,0)==0)
+	   || (include && !exclude)))
+      {
+	 Sub(i);
+	 i--;
+      }
+   }
+}
+
 
 // *** Manipulations with set of local files
 
@@ -416,11 +507,15 @@ void FileSet::LocalChmod(const char *dir,mode_t mask)
    }
 }
 
+FileInfo * FileSet::operator[](int i) const
+{
+   if(i >= fnum) return 0;
+   return files_sort[i];
+}
+
 FileInfo *FileSet::curr()
 {
-   if(ind<fnum)
-      return files[ind];
-   return 0;
+   return (*this)[ind];
 }
 FileInfo *FileSet::next()
 {
@@ -450,6 +545,60 @@ FileInfo::FileInfo(const FileInfo &fi)
    date=fi.date;
    size=fi.size;
 }
+
+#ifndef S_ISLNK
+# define S_ISLNK(mode) (S_IFLNK==(mode&S_IFMT))
+#endif
+
+void FileInfo::LocalFile(const char *name, bool follow_symlinks)
+{
+   if(!this->name)
+      SetName(name);
+
+   struct stat st;
+   if(lstat(name,&st)==-1)
+      return;
+
+check_again:
+   FileInfo::type t;
+   if(S_ISDIR(st.st_mode))
+      t=FileInfo::DIRECTORY;
+   else if(S_ISREG(st.st_mode))
+      t=FileInfo::NORMAL;
+#ifdef HAVE_LSTAT
+   else if(S_ISLNK(st.st_mode))
+   {
+      if(follow_symlinks)
+      {
+	 if(stat(name,&st)!=-1)
+	    goto check_again;
+	 // dangling symlink, don't follow it.
+      }
+      t=FileInfo::SYMLINK;
+   }
+#endif
+   else
+      return;   // ignore other type files
+
+   SetSize(st.st_size);
+   SetDate(st.st_mtime);
+   SetMode(st.st_mode&07777);
+   SetType(t);
+
+#ifdef HAVE_LSTAT
+   if(t==SYMLINK)
+   {
+      char *buf=(char*)alloca(st.st_size+1);
+      int res=readlink(name,buf,st.st_size);
+      if(res!=-1)
+      {
+	 buf[res]=0;
+	 SetSymlink(buf);
+      }
+   }
+#endif /* HAVE_LSTAT */
+}
+
 FileInfo::~FileInfo()
 {
    xfree(name);
