@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.h,v 1.13 2001/08/27 13:56:49 lav Exp $ */
+/* $Id: FileSet.h,v 1.17 2001/11/09 13:36:26 lav Exp $ */
 
 #ifndef FILESET_H
 #define FILESET_H
@@ -75,6 +75,8 @@ public:
 
    void SetName(const char *n);
    FileInfo(const char *n) { Init(); SetName(n); }
+   void LocalFile(const char *name, bool follow_symlinks);
+
    void SetMode(mode_t m) { mode=m; defined|=MODE; }
    void SetDate(time_t t) { date=t; defined|=DATE; defined&=~DATE_UNPREC; }
    void SetDateUnprec(time_t t)
@@ -106,17 +108,27 @@ public:
 
 class FileSet
 {
+public:
+   enum sort_e { BYNAME, BYSIZE, DIRSFIRST };
+
+private:
    FileInfo **files;
+
+   /* Alternate pointers when sort != NAME: */
+   FileInfo **files_sort;
+
    int	 fnum;
 
    int	 ind;
 
    void	 Sub(int);
+   bool sorted;
 
 public:
    FileSet()
    {
-      files=0;
+      files=files_sort=0;
+      sorted = false;
       fnum=0;
       ind=0;
    }
@@ -134,8 +146,11 @@ public:
    void	 SubtractAny(const FileSet *);
    void  SubtractOlderThan(time_t t);
    void  SubtractNotIn(const FileSet *);
+   void  Sort(sort_e newsort, bool casefold=false);
+   void  Unsort();
 
    void	 Exclude(const char *prefix,regex_t *exclude,regex_t *include);
+   void  Exclude(const char *prefix,const char *exclude,const char *include);
    void	 ExcludeDots();
 
    void	 rewind() { ind=0; }
@@ -164,7 +179,7 @@ public:
 	 f->SetDate(date);
    }
 
-   FileInfo * operator[](int i) const { return i<fnum?files[i]:0; }
+   FileInfo * operator[](int i) const;
 };
 
 #endif // FILESET_H
