@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpDirList.h,v 1.5 2001/10/27 10:05:49 lav Exp $ */
+/* $Id: FtpDirList.h,v 1.5.2.1 2001/12/14 18:48:44 lav Exp $ */
 
 #ifndef FTPDIRLIST_H
 #define FTPDIRLIST_H
@@ -29,8 +29,8 @@ class FtpDirList : public DirList
    Buffer *ubuf;
    char *pattern;
 
-   static char *FtpDirList::EPLF(const char *line, int len);
-	   
+   static char *EPLF(const char *line, int len);
+
 public:
    FtpDirList(ArgV *a,FileAccess *fa);
    ~FtpDirList();
