@@ -18,10 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpGlob.cc,v 1.15 2000/10/12 08:23:22 lav Exp $ */
+/* $Id: FtpGlob.cc,v 1.15.2.1 2002/01/15 16:20:21 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
+#include "trio.h"
 #include "xstring.h"
 #include <sys/types.h>
 #include <errno.h>
