@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpListInfo.h,v 1.6 2000/07/17 22:53:39 lav Exp $ */
+/* $Id: FtpListInfo.h,v 1.7 2001/10/25 13:42:56 lav Exp $ */
 
 #ifndef FTPLISTINFO_H
 #define FTPLISTINFO_H
@@ -44,7 +44,7 @@ class FtpListInfo : public ListInfo
    class FtpSplitList *slist;
 
 public:
-   static FileSet *ParseFtpLongList(const FileSet &lines,int *err);
+   static FileSet *ParseFtpLongList(const FileSet &lines,int *err,const char *tz);
 
 public:
    FtpListInfo(Ftp *session);
