@@ -18,10 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpSplitList.cc,v 1.9 2001/10/25 13:42:25 lav Exp $ */
+/* $Id: FtpSplitList.cc,v 1.9.2.1 2002/01/15 16:20:21 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
+#include "trio.h"
 #include "xstring.h"
 #include <sys/types.h>
 #include <errno.h>
