@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.h,v 1.4 1999/12/26 20:49:24 lav Exp $ */
+/* $Id: GetJob.h,v 1.5 2000/09/07 15:20:32 lav Exp $ */
 
 #ifndef GETJOB_H
 #define GETJOB_H
@@ -32,7 +32,8 @@ protected:
 
    bool delete_files;
    char *backup_file;
-   FDStream *local;
+   mode_t file_mode;
+   FileStream *local;
    bool reverse;
 
    void RemoveBackupFile();
