@@ -18,14 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.cc,v 1.137 2001/11/06 13:15:32 lav Exp $ */
+/* $Id: Http.cc,v 1.137.2.2 2002/01/21 16:18:35 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
-#ifdef NEED_TRIO
 #include "trio.h"
-#define vsnprintf trio_vsnprintf
-#endif
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -583,7 +579,6 @@ void Http::SendArrayInfoRequest()
 	 array_for_info[array_send].file);
       array_send++;
    }
-   keep_alive=false;
 }
 
 void Http::HandleHeaderLine(const char *name,const char *value)
@@ -1154,6 +1149,11 @@ int Http::Do()
 		  }
 	       }
 	       proto_version=(ver_major<<4)+ver_minor;
+
+	       // HTTP/1.1 does keep-alive by default
+	       if(proto_version>=0x11)
+		  keep_alive=true;
+
 	       if(!H_20X(status_code))
 	       {
 		  if(H_CONTINUE(status_code))
