@@ -18,14 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.h,v 1.33 2001/07/03 14:20:59 lav Exp $ */
+/* $Id: Http.h,v 1.35 2001/11/08 09:25:48 lav Exp $ */
 
 #ifndef HTTP_H
 #define HTTP_H
 
 #include "NetAccess.h"
 #include "buffer.h"
-#include "StatusLine.h"
 
 class Http : public NetAccess
 {
@@ -141,7 +140,7 @@ public:
    int StoreStatus();
    int SendEOT();
 
-   void	Connect(const char *h,const char *p);
+   void	ResetLocationData();
 
    void Close();
    const char *CurrentStatus();
