@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: HttpDir.cc,v 1.64 2001/07/02 13:11:40 lav Exp $ */
+/* $Id: HttpDir.cc,v 1.65 2001/11/06 13:15:32 lav Exp $ */
 
 #include <config.h>
 #include "ascii_ctype.h"
@@ -915,7 +915,7 @@ parse_url_again:
       {
 	 sprintf(info.month_name,"%02d",info.month+1);
 	 if(info.year==-1)
-	    info.year=guess_year(info.month,info.day);
+	    info.year=guess_year(info.month,info.day,info.hour,info.minute,SMTask::now);
       }
       if(info.perms[0]==0)
       {
