@@ -18,27 +18,22 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: HttpDir.h,v 1.8 2000/07/17 22:53:40 lav Exp $ */
+/* $Id: HttpDir.h,v 1.10 2001/06/18 13:42:34 lav Exp $ */
 
 #ifndef HTTPDIR_H
 #define HTTPDIR_H
 
 #include "Http.h"
 
-class HttpListInfo : public ListInfo
+class HttpListInfo : public GenericParseListInfo
 {
-   Http *session;
-
-   FA::fileinfo *get_info;
-   int get_info_cnt;
-
-   Buffer *ubuf;
-
+   FileSet *Parse(const char *buf,int len);
 public:
-   HttpListInfo(Http *session);
-   virtual ~HttpListInfo();
-   int Do();
-   const char *Status();
+   HttpListInfo(Http *session)
+      : GenericParseListInfo(session)
+      {
+	 get_time_for_dirs=false;
+      }
 };
 
 class ParsedURL;
@@ -79,23 +74,13 @@ public:
    void Resume();
 };
 
-class HttpGlob : public Glob
+class HttpGlob : public GenericParseGlob
 {
-   FileAccess *session;
-   char	 *dir;
-   const char *curr_dir;
-   FileSet *dir_list;
-   int   dir_index;
-   HttpGlob *updir_glob;
-
-   Buffer *ubuf;
-
+   FileSet *Parse(const char *buf,int len);
+   GenericParseGlob *MakeUpDirGlob();
 public:
-   int	 Do();
-   const char *Status();
-
-   HttpGlob(FileAccess *s,const char *n_pattern);
-   virtual ~HttpGlob();
+   HttpGlob(FileAccess *s,const char *n_pattern)
+      : GenericParseGlob(s,n_pattern) {}
 };
 
 #endif//HTTPDIR_H
