@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.cc,v 1.21 2001/07/26 09:57:18 lav Exp $ */
+/* $Id: Job.cc,v 1.22 2001/11/08 17:08:07 lav Exp $ */
 
 #include <config.h>
 #include <stdlib.h>
@@ -510,13 +510,16 @@ void Job::ShowRunStatus(StatusLine *sl)
 {
    if(waiting_num==0)
       return;
-   if(waiting_num==1)
-      waiting[0]->ShowRunStatus(sl);
-   else
+   Job *j=waiting[0];
+   if(waiting_num>1)
    {
-      waiting[(now/3)%waiting_num]->ShowRunStatus(sl);
+      j=waiting[(now/3)%waiting_num];
       current->TimeoutS(3);
    }
+   // let the job do something. Otherwise we can get 'idle' status.
+   if(j->Do()==MOVED)
+      current->Timeout(0);
+   j->ShowRunStatus(sl);
 }
 
 Job *Job::FindAnyChild()
