@@ -18,13 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.h,v 1.15 2001/05/29 06:22:59 lav Exp $ */
+/* $Id: Job.h,v 1.15.2.1 2002/01/15 16:20:22 lav Exp $ */
 
 #ifndef JOB_H
 #define JOB_H
 
 #include <stdarg.h>
-#include <stdio.h>
+#include "trio.h"
 #undef printf
 
 #include "SMTask.h"
