@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: LsCache.h,v 1.8 1999/09/19 19:58:24 lav Exp $ */
+/* $Id: LsCache.h,v 1.10 2000/02/12 10:12:54 lav Exp $ */
 
 #ifndef LSCACHE_H
 #define LSCACHE_H
@@ -57,10 +57,13 @@ class LsCache
 
    static void CheckSize();
 
+protected:
+   ~LsCache();
+
 public:
    static void Add(FileAccess *p_loc,const char *a,int m,const char *d,int l);
    static void Add(FileAccess *p_loc,const char *a,int m,const Buffer *ubuf);
-   static int Find(FileAccess *p_loc,const char *a,int m,char **d,int *l);
+   static int Find(FileAccess *p_loc,const char *a,int m,const char **d, int *l);
 
    enum change_mode { FILE_CHANGED, DIR_CHANGED, TREE_CHANGED };
    static void Changed(change_mode m,FileAccess *f,const char *what);
@@ -86,8 +89,6 @@ public:
    static long SizeLimit() { return sizelimit; }
    static void SetExpire(const TimeInterval &t) { ttl=t; }
 
-   ~LsCache();
-
    int Do();
 };
 
