@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.41 2001/06/18 13:42:53 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.44.2.1 2001/11/21 09:59:20 lav Exp $ */
 
 #include <config.h>
 
@@ -107,7 +107,7 @@ void NetAccess::Reconfig(const char *name)
    socket_buffer = ResMgr::Query("net:socket-buffer",c);
    socket_maxseg = ResMgr::Query("net:socket-maxseg",c);
    connection_limit = ResMgr::Query("net:connection-limit",c);
-   connection_takeover = ResMgr::Query("net:connection-takeover",c);
+   connection_takeover = ResMgr::QueryBool("net:connection-takeover",c);
 
    if(rate_limit)
       rate_limit->Reconfig(name,c);
@@ -269,12 +269,12 @@ void NetAccess::HandleTimeout()
 
 bool NetAccess::CheckTimeout()
 {
-   if(now-event_time>=timeout)
+   if(now >= event_time+timeout)
    {
       HandleTimeout();
       return(true);
    }
-   TimeoutS(timeout-(now-event_time));
+   TimeoutS(timeout-(time_t(now)-event_time));
    return(false);
 }
 
@@ -294,11 +294,11 @@ void NetAccess::NextPeer()
       try_time=0;	// try next address immediately
 }
 
-void NetAccess::Connect(const char *h,const char *p)
+void NetAccess::ResetLocationData()
 {
    Disconnect();
-   super::Connect(h,p);
    ClearPeer();
+   super::ResetLocationData();
 }
 
 void NetAccess::ConnectVerify()
@@ -376,15 +376,15 @@ RateLimit::~RateLimit()
 #define DEFAULT_MAX_COEFF 2
 void RateLimit::BytesPool::AdjustTime()
 {
-   if(SMTask::now>t)
-   {
-      time_t dif=SMTask::now-t;
+   double dif=TimeDiff(SMTask::now,t);
 
+   if(dif>0)
+   {
       // prevent overflow
       if((LARGE-pool)/dif < rate)
 	 pool = pool_max>0 ? pool_max : rate*DEFAULT_MAX_COEFF;
       else
-	 pool += dif*rate;
+	 pool += int(dif*rate+0.5);
 
       if(pool>pool_max && pool_max>0)
 	 pool=pool_max;
@@ -480,9 +480,9 @@ bool NetAccess::ReconnectAllowed()
    if(try_time==0)
       return true;
    long interval = ReconnectInterval();
-   if(now-try_time >= interval)
+   if(now >= try_time+interval)
       return true;
-   TimeoutS(interval-(now-try_time));
+   TimeoutS(interval-(time_t(now)-try_time));
    return false;
 }
 
@@ -491,7 +491,7 @@ const char *NetAccess::DelayingMessage()
    static char buf[80];
    if(connection_limit>0 && connection_limit<=CountConnections())
       return _("Connections limit reached");
-   long remains=ReconnectInterval()-(now-try_time);
+   long remains=ReconnectInterval()-(time_t(now)-try_time);
    if(remains<=0)
       return "";
    sprintf(buf,"%s: %ld",_("Delaying before reconnect"),remains);
@@ -510,9 +510,6 @@ bool NetAccess::NextTry()
    }
    retries++;
 
-//    assert(peer!=0);
-//    assert(peer_curr<peer_num);
-
    return true;
 }
 
