@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.h,v 1.22 2001/06/18 13:42:53 lav Exp $ */
+/* $Id: NetAccess.h,v 1.24 2001/11/06 13:15:33 lav Exp $ */
 
 #ifndef NETACCESS_H
 #define NETACCESS_H
@@ -101,8 +101,8 @@ public:
 
    void Reconfig(const char *name=0);
 
-   void Connect(const char *,const char *);
    void ConnectVerify();
+   void ResetLocationData();
 
    void Close();
 
@@ -119,7 +119,7 @@ public:
       int pool;
       int rate;
       int pool_max;
-      time_t t;
+      Time t;
 
       void AdjustTime();
       void Reset();
