@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ProcWait.cc,v 1.11 2001/06/18 13:44:54 lav Exp $ */
+/* $Id: ProcWait.cc,v 1.11.2.1 2002/01/15 16:20:22 lav Exp $ */
 
 #include <config.h>
 #include <sys/wait.h>
 #include <errno.h>
-#include <stdio.h>
+#include "trio.h"
 #include "ProcWait.h"
 #include "SignalHook.h"
 
