@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.h,v 1.28 2001/11/09 16:00:29 lav Exp $ */
+/* $Id: ResMgr.h,v 1.28.2.1 2002/01/15 16:20:22 lav Exp $ */
 
 #ifndef RESMGR_H
 #define RESMGR_H
 
-#include <stdio.h>
+#include "trio.h"
 #include <sys/types.h>
 #include <time.h>
 #include "xmalloc.h"
