@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.cc,v 1.50 2001/11/06 13:15:33 lav Exp $ */
+/* $Id: Resolver.cc,v 1.50.2.1 2002/01/15 16:19:24 lav Exp $ */
 
 #include <config.h>
 
@@ -26,7 +26,7 @@
 #include "SignalHook.h"
 #include <errno.h>
 #include <unistd.h>
-#include <stdio.h>
+#include "trio.h"
 #include <time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -204,6 +204,7 @@ int   Resolver::Do()
 	    close(0);	// no input will be needed.
 	    close(pipe_to_child[0]);
 	    pipe_to_child[0]=-1;
+	    buf=new IOBufferFDStream(new FDStream(pipe_to_child[1],"<pipe-out>"),IOBuffer::PUT);
 	    DoGethostbyname();
 	    _exit(0);
 	 }
@@ -818,9 +819,6 @@ void Resolver::DoGethostbyname()
    if(!use_fork && deleting)
       return;
 
-   if(!buf)
-      buf=new IOBufferFDStream(new FDStream(pipe_to_child[1],"<pipe-out>"),IOBuffer::PUT);
-
    if(addr_num==0)
    {
       buf->Put("E");
