@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SMTask.cc,v 1.20 2001/11/06 13:15:33 lav Exp $ */
+/* $Id: SMTask.cc,v 1.20.2.1 2002/01/15 16:20:23 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
 #include <time.h>
-#include <stdio.h>
+#include "trio.h"
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/types.h>
 # include <sys/time.h>
