@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SleepJob.cc,v 1.14 2001/05/29 06:23:00 lav Exp $ */
+/* $Id: SleepJob.cc,v 1.15 2001/11/06 13:15:33 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -76,7 +76,7 @@ int SleepJob::Do()
       return STALL;
    }
 
-   if(now-start_time>=next_time.Seconds())
+   if(now >= start_time+next_time.Seconds())
    {
       if(cmd)
       {
@@ -99,7 +99,7 @@ int SleepJob::Do()
       done=true;
       return MOVED;
    }
-   time_t diff=next_time.Seconds()-(now-start_time);
+   time_t diff=next_time.Seconds()-(time_t(now)-start_time);
    if(diff>1024)
       diff=1024;  // prevent overflow
    TimeoutS(diff);
