@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: StatusLine.cc,v 1.18 2001/11/09 16:00:29 lav Exp $ */
+/* $Id: StatusLine.cc,v 1.18.2.1 2002/01/15 16:20:23 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -27,11 +27,7 @@
 #endif
 #include <unistd.h>
 #include <sys/ioctl.h>
-#include <stdio.h>
-#ifdef NEED_TRIO
 #include "trio.h"
-#define vsnprintf trio_vsnprintf
-#endif
 #include <stdarg.h>
 #include "xstring.h"
 #include "xmalloc.h"
