@@ -18,14 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: bookmark.cc,v 1.8 2001/09/05 09:02:31 lav Exp $ */
+/* $Id: bookmark.cc,v 1.8.2.1 2002/01/15 16:20:23 lav Exp $ */
 
 #include <config.h>
 #include "bookmark.h"
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <stdio.h>
+#include "trio.h"
 
 #define super KeyValueDB
 
