@@ -18,13 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.151.2.1 2001/11/22 12:30:48 lav Exp $ */
+/* $Id: commands.cc,v 1.151.2.6 2002/01/27 08:55:48 lav Exp $ */
 
 #include <config.h>
 
 #include "modconfig.h"
 
-#include <stdio.h>
+#include "trio.h"
 #include <unistd.h>
 #include <errno.h>
 #include <ctype.h>
@@ -200,6 +200,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
    {"du",      cmd_du,  N_("du [options] <dirs>"),
 	 N_("Summarize disk usage.\n"
 	 " -a, --all             write counts for all files, not just directories\n"
+	 "     --block-size=SIZ  use SIZ-byte blocks\n"
 	 " -b, --bytes           print size in bytes\n"
 	 " -c, --total           produce a grand total\n"
 	 " -d, --max-depth=N     print the total for a directory (or file, with --all)\n"
@@ -385,22 +386,22 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 "be sure that any change of remote state because of quoted command\n"
 	 "is solid - it can be reset by reconnect at any time.\n")},
    {"recls",    cmd_cls,   0,
-	 N_("recls [<args>]"
+	 N_("recls [<args>]\n"
 	 "Same as `cls', but don't look in cache\n")},
    {"reget",   cmd_get,    0,
-	 N_("Usage: reget [OPTS] <rfile> [-o <lfile>]"
+	 N_("Usage: reget [OPTS] <rfile> [-o <lfile>]\n"
 	 "Same as `get -c'\n")},
    {"rels",    cmd_ls,	    0,
-	 N_("Usage: rels [<args>]"
+	 N_("Usage: rels [<args>]\n"
 	    "Same as `ls', but don't look in cache\n")},
    {"renlist", cmd_ls,	    0,
-	 N_("Usage: renlist [<args>]"
+	 N_("Usage: renlist [<args>]\n"
 	 "Same as `nlist', but don't look in cache\n")},
    {"repeat",  cmd_repeat, N_("repeat [delay] [command]"),
 	 N_("Repeat specified command with a delay between iterations.\n"
 	 "Default delay is one second, default command is empty.\n")},
    {"reput",   cmd_get,    0,
-	 N_("Usage: reput <lfile> [-o <rfile>]"
+	 N_("Usage: reput <lfile> [-o <rfile>]\n"
 	 "Same as `put -c'\n")},
    {"rm",      cmd_rm,	    N_("rm [-r] [-f] <files>"),
 	 N_("Remove remote files\n"
@@ -2240,7 +2241,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("Lftp | Version %s | Copyright (c) 1996-2001 Alexander V. Lukyanov\n"),VERSION);
+      _("Lftp | Version %s | Copyright (c) 1996-2002 Alexander V. Lukyanov\n"),VERSION);
    printf(
       _("This is free software with ABSOLUTELY NO WARRANTY. See COPYING for details.\n"));
    printf(
@@ -2326,7 +2327,7 @@ CMD(bookmark)
 	    value=session->GetConnectURL(flags);
 	    char *a=string_alloca(strlen(value)*3+2);
 	    // encode some more characters, special to CmdExec parser.
-	    url::encode_string(value,a,"&;|\"\\");
+	    url::encode_string(value,a,"&;|\"'\\");
 	    if(value[0] && value[strlen(value)-1]!='/')
 	       strcat(a,"/");
 	    value=a;
@@ -2453,6 +2454,7 @@ CMD(du)
       /* alias: both GNU-like max-depth and lftp-like maxdepth;
        * only document one of them. */
       {"bytes",no_argument,0,'b'},
+      {"block-size",required_argument,0,0},
       {"maxdepth",required_argument,0,'d'},
       {"total",no_argument,0,'c'},
       {"max-depth",required_argument,0,'d'},
@@ -2521,6 +2523,17 @@ CMD(du)
 	 separate_dirs = true;
 	 break;
       case 0:
+	 if(!strcmp(du_options[longopt].name, "block-size")) {
+	    if(!isdigit(optarg[0]) || atoi(optarg) == 0)
+	    {
+	       eprintf(_("%s: invalid block size `%s'\n"),op,optarg);
+	       return 0;
+	    }
+	    
+	    blocksize = atoi(optarg);
+	    break;
+	 }
+
 	 if(!strcmp(du_options[longopt].name, "exclude")) {
 	    exclude=optarg;
 	    break;
