@@ -18,11 +18,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: complete.cc,v 1.55 2001/11/09 16:00:30 lav Exp $ */
+/* $Id: complete.cc,v 1.55.2.1 2002/01/15 16:20:24 lav Exp $ */
 
 #include <config.h>
 
-#include <stdio.h>
+#include "trio.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
