@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: complete.h,v 1.3 2001/10/08 05:50:55 lav Exp $ */
+/* $Id: complete.h,v 1.3.2.1 2002/01/15 16:20:25 lav Exp $ */
 
 #ifndef COMPLETE_H
 #define COMPLETE_H
 
-#include <stdio.h>
+#include "trio.h"
 #include "CmdExec.h"
 
 extern CmdExec *completion_shell;
