@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.cc,v 1.213.2.2 2001/12/03 16:15:49 lav Exp $ */
+/* $Id: ftpclass.cc,v 1.213.2.4 2002/01/24 10:35:55 lav Exp $ */
 
 #include <config.h>
 
@@ -1219,7 +1219,7 @@ int   Ftp::Do()
 
 #ifdef USE_SSL
       // ssl for anonymous does not make sense.
-      if(!ftps && QueryBool("ssl-allow") && user && pass)
+      if(!ftps && !proxy && QueryBool("ssl-allow") && user && pass)
       {
 	 const char *auth=Query("ssl-auth",hostname);
 	 SendCmd2("AUTH",auth);
@@ -1986,6 +1986,13 @@ usual_return:
 notimeout_return:
    if(m==MOVED)
       return MOVED;
+#ifdef USE_SSL
+   if(data_ssl)
+   {
+      BlockOnSSL(data_ssl);
+   }
+   else
+#endif
    if(data_sock!=-1)
    {
       if(state==ACCEPTING_STATE)
@@ -2015,6 +2022,13 @@ notimeout_return:
 	 abort();
       }
    }
+#ifdef USE_SSL
+   if(control_ssl)
+   {
+      BlockOnSSL(control_ssl);
+   }
+   else
+#endif
    if(control_sock!=-1)
    {
       if(state==CONNECTING_STATE)
@@ -2920,6 +2934,7 @@ read_again:
    {
       if(!data_ssl_connected)
       {
+	 errno=0;
 	 res=SSL_connect(data_ssl);
 	 if(res<=0)
 	 {
@@ -2932,6 +2947,16 @@ read_again:
 	       return DO_AGAIN;
 	    else // error
 	    {
+	       if(SSL_get_error(data_ssl,res)==SSL_ERROR_SYSCALL)
+	       {
+		  if(ERR_get_error()==0)
+		     goto we_have_eof;
+		  if(NotSerious(errno))
+		  {
+		     Disconnect();
+		     return DO_AGAIN;
+		  }
+	       }
 	       SetError(FATAL,lftp_ssl_strerror("SSL connect"));
 	       return error_code;
 	    }
@@ -3045,8 +3070,9 @@ int   Ftp::Write(const void *buf,int size)
    {
       if(!data_ssl_connected)
       {
+	 errno=0;
 	 res=SSL_connect(data_ssl);
-	 if(res<=0)
+	 if(res<0)
 	 {
 	    if(BIO_sock_should_retry(res))
 	    {
@@ -3057,6 +3083,14 @@ int   Ftp::Write(const void *buf,int size)
 	       return DO_AGAIN;
 	    else // error
 	    {
+	       if(SSL_get_error(data_ssl,res)==SSL_ERROR_SYSCALL)
+	       {
+		  if(ERR_get_error()==0 || errno==0 || NotSerious(errno))
+		  {
+		     Disconnect();
+		     return DO_AGAIN;
+		  }
+	       }
 	       SetError(FATAL,lftp_ssl_strerror("SSL connect"));
 	       return error_code;
 	    }
@@ -3071,9 +3105,8 @@ int   Ftp::Write(const void *buf,int size)
 	    BlockOnSSL(control_ssl);
 	    return DO_AGAIN;
 	 }
-	 if(NotSerious(errno))
-	    DebugPrint("**** ",strerror(errno),0);
-	 else
+	 DebugPrint("**** ",strerror(errno),0);
+	 if(!NotSerious(errno))
 	    SetError(SEE_ERRNO,"SSL_write(data_ssl)");
 	 quit_sent=true;
 	 Disconnect();
