@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.h,v 1.80.2.2 2001/12/03 17:58:21 lav Exp $ */
+/* $Id: ftpclass.h,v 1.80.2.3 2002/01/15 16:20:25 lav Exp $ */
 
 #ifndef FTPCLASS_H
 #define FTPCLASS_H
 
-#include <stdio.h>
+#include "trio.h"
 #include <time.h>
 
 #include "NetAccess.h"
