@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: keyvalue.cc,v 1.10 2001/10/03 08:13:38 lav Exp $ */
+/* $Id: keyvalue.cc,v 1.10.2.1 2002/01/15 16:20:25 lav Exp $ */
 
 #include <config.h>
 #include "keyvalue.h"
 #include <unistd.h>
-#include <stdio.h>
+#include "trio.h"
 #include <fcntl.h>
 #include <errno.h>
 #include "xalloca.h"
