@@ -18,13 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: lftp.cc,v 1.45.2.1 2001/11/19 10:00:56 lav Exp $ */
+/* $Id: lftp.cc,v 1.45.2.2 2002/01/15 16:20:26 lav Exp $ */
 
 #include <config.h>
 
 #include "modconfig.h"
 
-#include <stdio.h>
+#include "trio.h"
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
