@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: mgetJob.h,v 1.2 1999/03/17 13:27:14 lav Exp $ */
+/* $Id: mgetJob.h,v 1.5 2000/01/22 16:27:31 lav Exp $ */
 
 #ifndef MGETJOB_H
 #define MGETJOB_H
@@ -27,19 +27,27 @@
 
 class mgetJob : public GetJob
 {
-   Glob *rg;
-   ArgV *args;
+   GlobURL *rg;
+   class mkdirJob *mkdir_job;
+   ArgV *mkdir_args;
+   int mkdir_base_arg;
+   ArgV *m_args;
+   char *output_dir;
+
+   bool	 make_dirs;
+   void	 make_directory(char *d);
+
+   void LocalGlob(const char *p);
 
 public:
    int	 Do();
-   int	 Done() { return(rg==0 && GetJob::Done()); }
    void	 PrintStatus(int);
    void	 ShowRunStatus(StatusLine *s);
 
-   mgetJob(FileAccess *session,ArgV *args);
+   mgetJob(FileAccess *session,ArgV *args,bool c,bool md);
    ~mgetJob();
 
-   bool	 make_dirs;
+   void OutputDir(char *o) { output_dir=o; }
 };
 
 #endif // MGETJOB_H
