@@ -18,16 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.42 2001/11/06 13:15:36 lav Exp $ */
+/* $Id: misc.cc,v 1.42.2.1 2002/01/15 16:20:26 lav Exp $ */
 
 #include <config.h>
-#ifdef NEED_TRIO
-#include "trio.h"
-#define vsnprintf trio_vsnprintf
-#endif
 #include "xmalloc.h"
 #include "xstring.h"
-#include <stdio.h>
+#include "trio.h"
 #include <pwd.h>
 #include <unistd.h>
 #include <errno.h>
