@@ -18,12 +18,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.h,v 1.27 2001/11/06 13:15:36 lav Exp $ */
+/* $Id: misc.h,v 1.27.2.1 2002/01/15 16:20:26 lav Exp $ */
 
 #ifndef MISC_H
 #define MISC_H
 
-#include <stdio.h>
+#include "trio.h"
 #include <sys/types.h>
 #include <sys/time.h>
 #ifdef TIME_WITH_SYS_TIME
