@@ -18,10 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: module.cc,v 1.7 2001/07/09 13:21:58 lav Exp $ */
+/* $Id: module.cc,v 1.7.2.1 2002/01/15 16:20:27 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
+#include "trio.h"
 #include <string.h>
 #ifdef HAVE_DLFCN_H
 # include <dlfcn.h>
