@@ -18,11 +18,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: netrc.cc,v 1.8 2001/07/03 13:39:43 lav Exp $ */
+/* $Id: netrc.cc,v 1.8.2.1 2002/01/15 16:20:27 lav Exp $ */
 
 #include <config.h>
 
-#include <stdio.h>
+#include "trio.h"
 #include <stdlib.h>
 #include "xstring.h"
 #include "netrc.h"
