@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: resource.cc,v 1.64 2001/11/12 13:39:01 lav Exp $ */
+/* $Id: resource.cc,v 1.64.2.1 2002/01/03 17:49:35 lav Exp $ */
 
 #include <config.h>
 
@@ -117,7 +117,7 @@ const char *OrderValidate(char **s)
 
    const char * const delim="\t ";
    char *s1=alloca_strdup(*s);
-   char *fixed=(char*)xmalloc(strlen(s1));
+   char *fixed=(char*)xmalloc(strlen(s1)+1);
    fixed[0]=0;
 
    for(s1=strtok(s1,delim); s1; s1=strtok(0,delim))
