@@ -18,10 +18,10 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: xmalloc.cc,v 1.9 2000/05/21 22:49:21 lav Exp $ */
+/* $Id: xmalloc.cc,v 1.9.2.1 2002/01/15 16:20:28 lav Exp $ */
 
 #include <config.h>
-#include <stdio.h>
+#include "trio.h"
 #include "xmalloc.h"
 
 static int memory_count=0;
